@@ -27,6 +27,8 @@
 ** 02110-1301, USA.
 */
 
+/* ****** ****** */
+
 /*
 **
 ** Author: Hongwei Xi (hwxi AT cs DOT bu DOT edu) 
@@ -66,32 +68,48 @@ extern void *alloca (size_t nsz) ; // [alloca.h]
 
 /* ****** ****** */
 
-extern ats_void_type ats_gc_init () ;
-extern ats_void_type
+extern
+ats_void_type ats_gc_init () ;
+
+extern
+ats_void_type
 ats_gc_markroot (ats_ptr_type p, ats_size_type bsz) ;
 
 /* ****** ****** */
 
-extern ats_ptr_type ats_malloc_ngc (ats_size_type n) ;
+extern
+ats_ptr_type
+ats_malloc_ngc (ats_size_type n) ;
 
-extern ats_ptr_type
+extern
+ats_ptr_type
 ats_calloc_ngc (ats_size_type nmemb, ats_size_type bsz) ;
 
-extern ats_void_type ats_free_ngc (const ats_ptr_type p) ;
+extern
+ats_void_type
+ats_free_ngc (const ats_ptr_type p) ;
 
-extern ats_ptr_type
+extern
+ats_ptr_type
 ats_realloc_ngc (const ats_ptr_type p, ats_size_type n) ;
 
 /* ****** ****** */
 
-extern ats_ptr_type ats_malloc_gc (ats_size_type bsz) ;
+extern
+ats_ptr_type
+ats_malloc_gc (ats_size_type bsz) ;
 
-extern ats_ptr_type
-ats_calloc_gc (ats_size_type nmemb, ats_size_type bsz) ;
+extern
+ats_ptr_type
+ats_calloc_gc
+(ats_size_type nmemb, ats_size_type bsz) ;
 
-extern ats_void_type ats_free_gc (const ats_ptr_type p) ;
+extern
+ats_void_type
+ats_free_gc (const ats_ptr_type p) ;
 
-extern ats_ptr_type
+extern
+ats_ptr_type
 ats_realloc_gc (const ats_ptr_type p, ats_size_type bsz) ;
 
 /* ****** ****** */
